@@ -2,7 +2,7 @@ from .app_command import AppCommand
 from .container_command import ContainerCommand
 from .info_command import InfoCommand
 from .report_command import ReportCommand
-from .devices_command import DevicesCommand
+from .device_command import DeviceCommand
 
 
 def available_commands(config):
@@ -11,5 +11,5 @@ def available_commands(config):
         'container': ContainerCommand(config),
         'info': InfoCommand(config),
         'report': ReportCommand(config),
-        'devices': DevicesCommand(config)
+        'device': DeviceCommand(config)
     }
